@@ -23,14 +23,9 @@ except ImportError:  # Django >=2.2
 try:
     if 'whitenoise.runserver_nostatic' in settings.INSTALLED_APPS:
         USE_STATICFILES = False
-    elif 'django.contrib.staticfiles' in settings.INSTALLED_APPS:
+    else:
         from django.contrib.staticfiles.handlers import StaticFilesHandler
         USE_STATICFILES = True
-    elif 'staticfiles' in settings.INSTALLED_APPS:
-        from staticfiles.handlers import StaticFilesHandler  # noqa
-        USE_STATICFILES = True
-    else:
-        USE_STATICFILES = False
 except ImportError:
     USE_STATICFILES = False
 
@@ -224,7 +219,8 @@ class Command(BaseCommand):
 
     def inner_run(self, options):
         try:
-            from werkzeug import run_simple, DebuggedApplication
+            from werkzeug import run_simple
+            from werkzeug.debug import DebuggedApplication
             from werkzeug.serving import WSGIRequestHandler as _WSGIRequestHandler
 
             # Set colored output
